@@ -686,8 +686,8 @@ class PhIDEBase(object):
         self.s3_job_path = dv.DAGS_S3_PHJOBS_PATH + self.dag_name + "/" + self.job_full_name
         self.submit_prefix = "s3a://" + dv.TEMPLATE_BUCKET + "/" + dv.CLI_VERSION + self.s3_job_path + "/"
 
-        stream = self.phs3.open_object(dv.TEMPLATE_BUCKET, dv.CLI_VERSION + self.s3_job_path + "/phconf.yaml")
-        config = PhYAMLConfig()
+        # stream = self.phs3.open_object(dv.TEMPLATE_BUCKET, dv.CLI_VERSION + self.s3_job_path + "/phconf.yaml")
+        # config = PhYAMLConfig()
         # config.load_yaml(stream)
         # self.runtime = config.spec.containers.runtime
         # self.command = config.spec.containers.command
@@ -791,6 +791,7 @@ class PhIDEBase(object):
                 raise Exception("Job运行失败")
                 break
 
+        return 0
 
 
     def status(self, **kwargs):
